summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/gwclientstream.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/gwclientstream.h')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/gwclientstream.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/gwclientstream.h b/kopete/protocols/groupwise/libgroupwise/gwclientstream.h
index 5ae5ec8c..2d0cef92 100644
--- a/kopete/protocols/groupwise/libgroupwise/gwclientstream.h
+++ b/kopete/protocols/groupwise/libgroupwise/gwclientstream.h
@@ -33,8 +33,8 @@ class TLSHandler;
typedef struct NovellDN
{
- QString dn;
- QString server;
+ TQString dn;
+ TQString server;
};
class ClientStream : public Stream
@@ -86,7 +86,7 @@ public:
BindConflict // resource in-use
};
- ClientStream(Connector *conn, TLSHandler *tlsHandler=0, QObject *parent=0);
+ ClientStream(Connector *conn, TLSHandler *tlsHandler=0, TQObject *parent=0);
~ClientStream();
void connectToServer(const NovellDN &id, bool auth=true);
@@ -95,15 +95,15 @@ public:
bool isAuthenticated() const;
// login params
- void setUsername(const QString &s);
- void setPassword(const QString &s);
- void setRealm(const QString &s);
+ void setUsername(const TQString &s);
+ void setPassword(const TQString &s);
+ void setRealm(const TQString &s);
void continueAfterParams();
// security options (old protocol only uses the first !)
void setAllowPlain(bool);
void setRequireMutualAuth(bool);
- void setLocalAddr(const QHostAddress &addr, Q_UINT16 port);
+ void setLocalAddr(const TQHostAddress &addr, Q_UINT16 port);
void close();
@@ -122,11 +122,11 @@ public:
void write( Request * request );
int errorCondition() const;
- QString errorText() const;
-// # QDomElement errorAppSpec() const; // redondo
+ TQString errorText() const;
+// # TQDomElement errorAppSpec() const; // redondo
// extrahttp://bugs.kde.org/show_bug.cgi?id=85158
/*# void writeDirect(const QString &s); // must be for debug testing*/
void setNoopTime(int mills);
signals:
@@ -135,8 +135,8 @@ signals:
//void needAuthParams(bool user, bool pass, bool realm);
void authenticated(); // this signal is ordinarily emitted in processNext
void warning(int);
// # void incomingXml(const QString &s); // signals emitted in processNext but don't seem to go anywhere...
// # void outgoingXml(const QString &s); //
// void readyRead(); //signals that there is a transfer ready to be read - defined in stream
public slots:
void continueAfterWarning();
@@ -147,7 +147,7 @@ private slots:
/**
* collects wire ready outgoing data from the core protocol and sends
*/
- void cp_outgoingData( const QByteArray& );
+ void cp_outgoingData( const TQByteArray& );
/**
* collects parsed incoming data as a transfer from the core protocol and queues
*/
@@ -122,11 +122,11 @@ public:
// extrahttp://bugs.kde.org/show_bug.cgi?id=85158
-/*# void writeDirect(const QString &s); // must be for debug testing*/
+/*# void writeDirect(const TQString &s); // must be for debug testing*/
void setNoopTime(int mills);
signals:
@@ -135,8 +135,8 @@ signals:
void authenticated(); // this signal is ordinarily emitted in processNext
void warning(int);
-// # void incomingXml(const QString &s); // signals emitted in processNext but don't seem to go anywhere...
-// # void outgoingXml(const QString &s); //
+// # void incomingXml(const TQString &s); // signals emitted in processNext but don't seem to go anywhere...
+// # void outgoingXml(const TQString &s); //
// void readyRead(); //signals that there is a transfer ready to be read - defined in stream
public slots: